@@ -4,6 +4,21 @@ use 5;
 use warnings;
 use strict;
 
+#######################################################################
+#  Acme::Pythonic::Functions is Copyright (C) 2009-2012, Hauke Lubenow.
+#  This module is free software; you can redistribute it and/or modify it
+#  under the same terms as Perl 5.14.2.
+#  For more details, see the full text of the licenses in the directory LICENSES.
+#  The full text of the licenses can also be found in the documents
+#  'perldoc perlgpl' and 'perldoc perlartistic' of the official Perl 5.14.2-distribution. In case of any contradictions, these 'perldoc'-texts decide.
+#
+#  This program is distributed in the hope that it will be useful, but
+#  without any warranty; without even the implied warranty of
+#  merchantability or fitness for a particular purpose.
+#  For more details, see the full texts of the licenses in the directory
+#  LICENSES and in the 'perldoc'-texts mentioned above.
+#######################################################################
+
 use Carp;
 
 use Exporter;
@@ -11,7 +26,7 @@ use Exporter;
 our ($VERSION, @ISA, @EXPORT);
 @ISA         = qw(Exporter);
 
-$VERSION     = 0.30;
+$VERSION     = 0.35;
 
 @EXPORT      = qw(append endswith extend has_key insert isdigit isin isdir isfile len lstrip lstrip2 osname pront readfile remove replace rstrip rstrip2 startswith strip writefile);
 
@@ -466,7 +481,7 @@ Acme::Pythonic::Functions - Python-like functions for Perl
 
 =head1 VERSION
 
-Version 0.30
+Version 0.35
 
 =head1 SYNOPSIS
 
@@ -763,15 +778,23 @@ Tells the name of the operating-system, similar to "os.name" in Python.
 
 =back
 
-=head1 AUTHOR, COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2009, 2012 Hauke Lubenow, <hlubenow2@gmx.net>, all rights reserved.
+Hauke Lubenow, <hlubenow2@gmx.net>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+Acme::Pythonic::Functions is Copyright (C) 2009-2012, Hauke Lubenow.
+
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl 5.14.2.
+For more details, see the full text of the licenses in the directory LICENSES.
+The full text of the licenses can also be found in the documents 'perldoc perlgpl' and 'perldoc perlartistic' of the official Perl 5.14.2-distribution. In case of any contradictions, these 'perldoc'-texts decide.
+
+This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. For more details, see the full texts of the licenses in the directory LICENSES and in the 'perldoc'-texts mentioned above.
 
 =head1 SEE ALSO
 
 L<Acme::Pythonic>
 
 =cut
+
